.. :api_reference:

API Reference
-------------

If you are searching for information on a specific function, class, or method,
this part of the documentation is for you.

:mod:`client` Module
~~~~~~~~~~~~~~~~~~~~

.. automodule:: fixerio.client
    :noindex:
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`exceptions` Module
~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: fixerio.exceptions
    :noindex:
    :members:
    :undoc-members:
    :show-inheritance:
